@@ -14,9 +14,11 @@ demonstrated to work earlier in the file are used by those later in the file
 
 from __future__ import division, absolute_import
 
+import sys
 import warnings
 import unittest as pyunit
 
+from twisted.python.filepath import FilePath
 from twisted.python.util import FancyEqMixin
 from twisted.python.reflect import (
     prefixedMethods, accumulateMethods, fullyQualifiedName)
@@ -957,17 +959,20 @@ class ResultOfAssertionsTests(unittest.SynchronousTestCase):
     L{SynchronousTestCase.failureResultOf}, and
     L{SynchronousTestCase.assertNoResult}.
     """
+
     result = object()
     failure = Failure(Exception("Bad times"))
 
-    def test_withoutSuccessResult(self):
+
+    def test_withoutResult(self):
         """
         L{SynchronousTestCase.successResultOf} raises
         L{SynchronousTestCase.failureException} when called with a L{Deferred}
         with no current result.
         """
         self.assertRaises(
-            self.failureException, self.successResultOf, Deferred())
+            self.failureException, self.successResultOf, Deferred()
+        )
 
 
     def test_successResultOfWithFailure(self):
@@ -977,7 +982,8 @@ class ResultOfAssertionsTests(unittest.SynchronousTestCase):
         with a failure result.
         """
         self.assertRaises(
-            self.failureException, self.successResultOf, fail(self.failure))
+            self.failureException, self.successResultOf, fail(self.failure)
+        )
 
 
     def test_successResultOfWithFailureHasTraceback(self):
@@ -992,14 +998,15 @@ class ResultOfAssertionsTests(unittest.SynchronousTestCase):
             self.assertIn(self.failure.getTraceback(), str(e))
 
 
-    def test_withoutFailureResult(self):
+    def test_failureResultOfWithoutResult(self):
         """
         L{SynchronousTestCase.failureResultOf} raises
         L{SynchronousTestCase.failureException} when called with a L{Deferred}
         with no current result.
         """
         self.assertRaises(
-            self.failureException, self.failureResultOf, Deferred())
+            self.failureException, self.failureResultOf, Deferred()
+        )
 
 
     def test_failureResultOfWithSuccess(self):
@@ -1009,58 +1016,90 @@ class ResultOfAssertionsTests(unittest.SynchronousTestCase):
         with a success result.
         """
         self.assertRaises(
-            self.failureException, self.failureResultOf, succeed(self.result))
+            self.failureException, self.failureResultOf, succeed(self.result)
+        )
+
 
     def test_failureResultOfWithWrongFailure(self):
         """
         L{SynchronousTestCase.failureResultOf} raises
         L{SynchronousTestCase.failureException} when called with a L{Deferred}
-        with a failure type that was not expected.
+        that fails with an exception type that was not expected.
         """
         self.assertRaises(
-            self.failureException, self.failureResultOf, fail(self.failure),
-            KeyError)
+            self.failureException,
+            self.failureResultOf, fail(self.failure), KeyError
+        )
 
 
     def test_failureResultOfWithWrongFailureOneExpectedFailure(self):
         """
         L{SynchronousTestCase.failureResultOf} raises
         L{SynchronousTestCase.failureException} when called with a L{Deferred}
-        with a failure type that was not expected, and the
+        that fails with an exception type that was not expected, and the
+        L{SynchronousTestCase.failureException} message contains the expected
+        exception type.
+        """
+        try:
+            self.failureResultOf(fail(self.failure), KeyError)
+        except self.failureException as e:
+            self.assertIn(
+                "Failure of type ({0}.{1}) expected on".format(
+                    KeyError.__module__, KeyError.__name__
+                ),
+                str(e)
+            )
+
+
+    def test_failureResultOfWithWrongFailureOneExpectedFailureHasTB(self):
+        """
+        L{SynchronousTestCase.failureResultOf} raises
+        L{SynchronousTestCase.failureException} when called with a L{Deferred}
+        that fails with an exception type that was not expected, and the
         L{SynchronousTestCase.failureException} message contains the original
-        failure traceback as well as the expected failure type
+        failure traceback.
         """
         try:
             self.failureResultOf(fail(self.failure), KeyError)
         except self.failureException as e:
             self.assertIn(self.failure.getTraceback(), str(e))
-            self.assertIn(
-                "Failure of type ({0}.{1}) expected on".format(
-                    KeyError.__module__, KeyError.__name__),
-                str(e))
 
 
-    def test_failureResultOfWithWrongFailureMultiExpectedFailure(self):
+    def test_failureResultOfWithWrongFailureMultiExpectedFailures(self):
         """
         L{SynchronousTestCase.failureResultOf} raises
         L{SynchronousTestCase.failureException} when called with a L{Deferred}
-        with a failure type that was not expected, and the
+        with an exception type that was not expected, and the
+        L{SynchronousTestCase.failureException} message contains the expected
+        exception types in the error message.
+        """
+        try:
+            self.failureResultOf(fail(self.failure), KeyError, IOError)
+        except self.failureException as e:
+            self.assertIn(
+                "Failure of type ({0}.{1} or {2}.{3}) expected on".format(
+                    KeyError.__module__, KeyError.__name__,
+                    IOError.__module__, IOError.__name__,
+                ),
+                str(e)
+            )
+
+
+    def test_failureResultOfWithWrongFailureMultiExpectedFailuresHasTB(self):
+        """
+        L{SynchronousTestCase.failureResultOf} raises
+        L{SynchronousTestCase.failureException} when called with a L{Deferred}
+        with an exception type that was not expected, and the
         L{SynchronousTestCase.failureException} message contains the original
-        failure traceback as well as the expected failure types in the error
-        message
+        failure traceback in the error message.
         """
         try:
             self.failureResultOf(fail(self.failure), KeyError, IOError)
         except self.failureException as e:
             self.assertIn(self.failure.getTraceback(), str(e))
-            self.assertIn(
-                "Failure of type ({0}.{1} or {2}.{3}) expected on".format(
-                    KeyError.__module__, KeyError.__name__,
-                    IOError.__module__, IOError.__name__),
-                str(e))
 
 
-    def test_withSuccessResult(self):
+    def test_successResultOfWithSuccessResult(self):
         """
         When passed a L{Deferred} which currently has a result (ie,
         L{Deferred.addCallback} would cause the added callback to be called
@@ -1071,20 +1110,22 @@ class ResultOfAssertionsTests(unittest.SynchronousTestCase):
             self.result, self.successResultOf(succeed(self.result)))
 
 
-    def test_withExpectedFailureResult(self):
+    def test_failureResultOfWithExpectedFailureResult(self):
         """
         When passed a L{Deferred} which currently has a L{Failure} result (ie,
         L{Deferred.addErrback} would cause the added errback to be called
         before C{addErrback} returns), L{SynchronousTestCase.failureResultOf}
-        returns that L{Failure} if that L{Failure}'s type is expected.
+        returns that L{Failure} if its contained exception type is expected.
         """
         self.assertIdentical(
             self.failure,
-            self.failureResultOf(fail(self.failure), self.failure.type,
-                                 KeyError))
+            self.failureResultOf(
+                fail(self.failure), self.failure.type, KeyError
+            )
+        )
 
 
-    def test_withFailureResult(self):
+    def test_failureResultOfWithFailureResult(self):
         """
         When passed a L{Deferred} which currently has a L{Failure} result
         (ie, L{Deferred.addErrback} would cause the added errback to be called
@@ -1092,32 +1133,36 @@ class ResultOfAssertionsTests(unittest.SynchronousTestCase):
         returns that L{Failure}.
         """
         self.assertIdentical(
-            self.failure, self.failureResultOf(fail(self.failure)))
+            self.failure, self.failureResultOf(fail(self.failure))
+        )
 
 
     def test_assertNoResultSuccess(self):
         """
         When passed a L{Deferred} which currently has a success result (see
-        L{test_withSuccessResult}), L{SynchronousTestCase.assertNoResult} raises
-        L{SynchronousTestCase.failureException}.
+        L{test_withSuccessResult}), L{SynchronousTestCase.assertNoResult}
+        raises L{SynchronousTestCase.failureException}.
         """
         self.assertRaises(
-            self.failureException, self.assertNoResult, succeed(self.result))
+            self.failureException, self.assertNoResult, succeed(self.result)
+        )
 
 
     def test_assertNoResultFailure(self):
         """
         When passed a L{Deferred} which currently has a failure result (see
-        L{test_withFailureResult}), L{SynchronousTestCase.assertNoResult} raises
-        L{SynchronousTestCase.failureException}.
+        L{test_withFailureResult}), L{SynchronousTestCase.assertNoResult}
+        raises L{SynchronousTestCase.failureException}.
         """
         self.assertRaises(
-            self.failureException, self.assertNoResult, fail(self.failure))
+            self.failureException, self.assertNoResult, fail(self.failure)
+        )
 
 
     def test_assertNoResult(self):
         """
         When passed a L{Deferred} with no current result,
+        L{SynchronousTestCase.assertNoResult} does not raise an exception.
         """
         self.assertNoResult(Deferred())
 
@@ -1161,6 +1206,27 @@ class ResultOfAssertionsTests(unittest.SynchronousTestCase):
 
 
 
+if sys.version_info >= (3, 5):
+    _p = FilePath(__file__).parent().child("_assertiontests.py.3only")
+    with _p.open() as _f:
+        exec(_f.read())
+    del _p, _f
+else:
+    class ResultOfCoroutineAssertionsTests(unittest.SynchronousTestCase):
+        """
+        A dummy class to show that this test file was discovered but the tests
+        are unable to be run in this version of Python.
+        """
+        skip = "async/await is not available before Python 3.5"
+
+        def test_notAvailable(self):
+            """
+            A skipped test to show that this was not run because the Python is
+            too old.
+            """
+
+
+
 class AssertionNamesTests(unittest.SynchronousTestCase):
     """
     Tests for consistency of naming within TestCase assertion methods
